@@ -519,7 +519,17 @@ void GrammarCheck::updateLTStatus(){
 QString GrammarCheck::languageFromHunspellToLanguageTool(QString language)
 {
 	language.replace('_', '-');
-	return languageMapping.value(language, language);
+    QString result=language;
+    if(languageMapping.contains(language)){
+        result=languageMapping.value(language, language);
+    }else{
+        // just deliver the first part of the language code if no mapping is known
+        int i=language.indexOf('-');
+        if(i>=0){
+            result=language.left(i);
+        }
+    }
+    return result;
 }
 
 /*!
@@ -666,7 +676,7 @@ void GrammarCheckLanguageToolJSON::tryToStart()
     connect(javaProcess, SIGNAL(finished(int,QProcess::ExitStatus)), javaProcess, SLOT(deleteLater()));
     connect(this, SIGNAL(destroyed()), javaProcess, SLOT(deleteLater()));
 
-    javaProcess->start(quoteSpaces(javaPath),QStringList()<< "-cp" << quoteSpaces(ltPath) << ltArguments.split(" ")); // check sdm
+    javaProcess->start(javaPath,QStringList()<< "-cp" << ltPath << ltArguments.split(" ")); // check sdm
     javaProcess->waitForStarted(500);
     javaProcess->waitForReadyRead(500);
     errorText=javaProcess->readAllStandardError();
