@@ -6,9 +6,10 @@
 #include "buildmanager.h"
 #include "latexdocument.h"
 #include "texstudio.h"
-#include "PDFDocument.h"
 #include "usermacro.h"
 #include <QCryptographicHash>
+#include "PDFDocument.h"
+
 
 //Q_DECLARE_METATYPE(QDocument *)
 //Q_DECLARE_METATYPE(LatexDocuments *)
@@ -22,8 +23,8 @@ Q_DECLARE_METATYPE(SubScriptObject *)
 Q_DECLARE_METATYPE(QList<LatexDocument *>)
 #ifndef NO_POPPLER_PREVIEW
 //Q_DECLARE_METATYPE(PDFDocument *)
-//Q_DECLARE_METATYPE(PDFWidget *)
-Q_DECLARE_METATYPE(QList<PDFDocument *>)
+Q_DECLARE_METATYPE(PDFWidget *)
+//Q_DECLARE_METATYPE(QList<PDFDocument *>)
 #endif
 //Q_DECLARE_METATYPE(QString *)
 
@@ -117,7 +118,7 @@ QString *getStrPtr(QJSValue value)
 	return reinterpret_cast<QString *>(ptr ^ pointerObsfuscationKey());
 }
 
-QJSValue getSetStrValue(QJSEngine *engine)
+QJSValue getSetStrValue(QJSEngine */*engine*/)
 {
 	/*bool setterMode = context->argumentCount() == 1;
 	QString *s = getStrPtr(context->thisObject());
@@ -155,7 +156,7 @@ scriptengine::scriptengine(QObject *parent) : QObject(parent), triggerId(-1), m_
     qmlRegisterType<QEditor>("com.txs.qmlcomponents", 1, 0, "QEditor");
 #ifndef NO_POPPLER_PREVIEW
     //qmlRegisterType<PDFDocument>("com.txs.qmlcomponents", 1, 0, "PDFDocument");
-    //qmlRegisterType<PDFWidget>("com.txs.qmlcomponents", 1, 0, "PDFWidget");
+    qmlRegisterType<PDFWidget>("com.txs.qmlcomponents", 1, 0, "PDFWidget");
 #endif
 
 	//qmlRegisterType<QList<LatexDocument *> >();
