@@ -48,6 +48,7 @@ void SyntaxCheck::setErrFormat(int errFormat)
 void SyntaxCheck::putLine(QDocumentLineHandle *dlh, StackEnvironment previous, TokenStack stack, bool clearOverlay, int hint)
 {
 	REQUIRE(dlh);
+    if(previous.isEmpty()) return; // sanity check as activeEnv at least contains "normal"
 	SyntaxLine newLine;
 	dlh->ref(); // impede deletion of handle while in syntax check queue
 	dlh->lockForRead();
@@ -377,7 +378,36 @@ int SyntaxCheck::containsEnv(const LatexParser &parser, const QString &name, con
 			}
 		}
 	}
-	return 0;
+    return 0;
+}
+/*!
+ * \brief check if math env is active
+ *
+ * Similar to containsEnv, but determines if math is active as it can be disabled by a virtual text env
+ * e.g. $abc \textbf{text}$
+ * \param parser reference to LatexParser. It is used to access environment aliases, e.g. equation is also a math environment
+ * \param envs stack of environements
+ * \return math is active (true) or not (false)
+ */
+bool SyntaxCheck::checkMathEnvActive(const LatexParser &parser, const StackEnvironment &envs)
+{
+    for (int i = envs.size() - 1; i > -1; --i) {
+        Environment env = envs.at(i);
+        if (env.name == "math") {
+                return true;
+        }
+        if (env.name == "text") {
+                return false;
+        }
+        if (parser.environmentAliases.contains(env.name)) {
+            QStringList altEnvs = parser.environmentAliases.values(env.name);
+            foreach (const QString &altEnv, altEnvs) {
+                if (altEnv == "math")
+                    return true;
+            }
+        }
+    }
+    return false;
 }
 
 /*!
@@ -545,7 +575,7 @@ void SyntaxCheck::checkLine(const QString &line, Ranges &newRanges, StackEnviron
 			QString word = line.mid(tk.start, tk.length);
 			QStringList forbiddenSymbols;
 			forbiddenSymbols<<"^"<<"_";
-            if(forbiddenSymbols.contains(word) && !containsEnv(*ltxCommands, "math", activeEnv) && tk.subtype!=Token::formula){
+            if(forbiddenSymbols.contains(word) && !checkMathEnvActive(*ltxCommands, activeEnv) && tk.subtype!=Token::formula){
 				Error elem;
 				elem.range = QPair<int, int>(tk.start, tk.length);
 				elem.type = ERR_MathCommandOutsideMath;
@@ -573,12 +603,34 @@ void SyntaxCheck::checkLine(const QString &line, Ranges &newRanges, StackEnviron
                 env.level = tk.level;
                 env.startingColumn=tk.start+1;
                 env.endingColumn=tk.start+tk.length-1;
-                activeEnv.push(env);
+                // avoid stacking same env (e.g. braces in braces, see #2411 )
+                Environment topEnv=activeEnv.top();
+                if(topEnv.name!=env.name)
+                    activeEnv.push(env);
             }
             newRanges.append(elem);
         }
+        // force text != math when text command is used, i.e. \textbf in math env, see #2603
+        if(tk.subtype==Token::text){
+            if(tk.type==Token::braces){
+                // add to active env
+                // invalidates math env as active
+                Environment env;
+                env.name = "text";
+                env.id = 1; // to be changed
+                env.dlh = dlh;
+                env.ticket = ticket;
+                env.level = tk.level;
+                env.startingColumn=tk.start+1;
+                env.endingColumn=tk.start+tk.length-1;
+                // avoid stacking same env (e.g. braces in braces, see #2411 )
+                Environment topEnv=activeEnv.top();
+                if(topEnv.name!=env.name)
+                    activeEnv.push(env);
+            }
+        }
         // spell checking
-        if (speller->inlineSpellChecking && tk.type == Token::word && (tk.subtype == Token::text || tk.subtype == Token::title || tk.subtype == Token::shorttitle || tk.subtype == Token::todo || tk.subtype == Token::none)  && tk.length >= 3 && speller) {
+        if (speller->inlineSpellChecking && tk.type == Token::word && (tk.subtype == Token::text || tk.subtype == Token::title || tk.subtype == Token::shorttitle || tk.subtype == Token::todo || tk.subtype == Token::none)  && speller) {
             int tkLength=tk.length;
             QString word = tk.getText();
             if(i+1 < tl.length()){
@@ -605,7 +657,7 @@ void SyntaxCheck::checkLine(const QString &line, Ranges &newRanges, StackEnviron
                 }
             }
             word = latexToPlainWordwithReplacementList(word, mReplacementList); //remove special chars
-            if (speller->hideNonTextSpellingErrors && (containsEnv(*ltxCommands, "math", activeEnv)||containsEnv(*ltxCommands, "picture", activeEnv)) && tk.subtype!=Token::text){
+            if (speller->hideNonTextSpellingErrors && (checkMathEnvActive(*ltxCommands, activeEnv)||containsEnv(*ltxCommands, "picture", activeEnv)) ){
                 word.clear();
                 tk.ignoreSpelling=true;
             }else{
@@ -619,14 +671,14 @@ void SyntaxCheck::checkLine(const QString &line, Ranges &newRanges, StackEnviron
                     newRanges.append(elem);
                 }
             }
-            if (!word.isEmpty() && !speller->check(word) ) {
+            if (tkLength>=3 && !word.isEmpty() && !speller->check(word) ) {
                 if (word.endsWith('-') && speller->check(word.left(word.length() - 1)))
                     continue; // word ended with '-', without that letter, word is correct (e.g. set-up / german hypehantion)
                 if(word.endsWith('.')){
                     tkLength--; // don't take point into misspelled word
                 }
                 Error elem;
-                elem.range = QPair<int, int>(tk.start, tk.length);
+                elem.range = QPair<int, int>(tk.start, tkLength);
                 elem.type = ERR_spelling;
                 newRanges.append(elem);
             }
@@ -771,7 +823,7 @@ void SyntaxCheck::checkLine(const QString &line, Ranges &newRanges, StackEnviron
                                     }
                                 }
                             }
-                            elem.range = QPair<int, int>(start, end);
+                            elem.range = QPair<int, int>(start, end-start);
                             elem.type = ERR_highlight;
                             elem.format=mFormatList.value(key);
                             newRanges.append(elem);
@@ -1122,20 +1174,14 @@ void SyntaxCheck::checkLine(const QString &line, Ranges &newRanges, StackEnviron
 		if (tk.subtype == Token::keyVal_val) {
 			//figure out keyval
 			QString word = line.mid(tk.start, tk.length);
+            if(word=="{"){
+                continue; // assume open brace is always valid
+            }
 			// first get command
-			Token cmd = Parsing::getCommandTokenFromToken(tl, tk);
-			QString command = line.mid(cmd.start, cmd.length);
-			// figure out key
-			QString key;
-			for (int k = i - 1; k >= 0; k--) {
-				Token elem = tl.at(k);
-				if (elem.level == tk.level - 1) {
-					if (elem.type == Token::keyVal_key) {
-						key = line.mid(elem.start, elem.length);
-					}
-					break;
-				}
-			}
+            QString command = tk.optionalCommandName;
+            int index=command.indexOf('/');
+            QString key=command.mid(index+1);
+            command=command.left(index);
 			// find if values are defined
 			QString elem;
             foreach(elem, ltxCommands->possibleCommands.keys()) {
