@@ -35,7 +35,7 @@
 #include "searchresultwidget.h"
 #include "unicodeinsertion.h"
 #include "tablemanipulation.h"
-#include "PDFDocument.h"
+//#include "PDFDocument.h"
 #include <QSplashScreen>
 #include "session.h"
 #include "sessionlist.h"
@@ -64,7 +64,10 @@ class SymbolListModel;
 class SymbolWidget;
 class StructureTreeView;
 
-Q_DECLARE_METATYPE(QSet<QString>)
+//Q_DECLARE_METATYPE(QSet<QString>)
+#if QT_VERSION_MAJOR<6
+Q_DECLARE_METATYPE(std::set<QString>)
+#endif
 
 class Texstudio : public QMainWindow
 {
@@ -226,6 +229,9 @@ private:
 
     bool parseStruct(StructureEntry* se, QVector<QTreeWidgetItem *> &rootVector, QSet<LatexDocument*> *visited=nullptr, QList<QTreeWidgetItem *> *todoList=nullptr, int currentColor=0);
     void parseStructLocally(StructureEntry* se, QVector<QTreeWidgetItem *> &rootVector, QList<QTreeWidgetItem *> *todoList=nullptr, QList<QTreeWidgetItem *> *labelList=nullptr, QList<QTreeWidgetItem *> *magicList=nullptr, QList<QTreeWidgetItem *> *biblioList=nullptr);
+#ifndef QT_NO_DEBUG
+    void checkForShortcutDuplicate();
+#endif
 private slots:
     void updateTOCs();
 
@@ -246,6 +252,7 @@ private slots:
     void closeDocument();
     void copyFileName();
     void copyFilePath();
+    void showInGraphicalShell_();
     void toggleSingleDocMode();
     void expandSubitems();
     void collapseSubitems();
@@ -267,7 +274,7 @@ protected slots:
 	void fileMakeTemplate();
 	void fileOpen();
 	void fileRestoreSession(bool showProgress = true, bool warnMissing = true);
-	void fileSave(const bool saveSilently = false);
+    void fileSave(const bool saveSilently = false,QEditor *editor=nullptr);
 	void fileSaveAll();
     void fileSaveAllFromTimer();
 	void fileSaveAll(bool alsoUnnamedFiles, bool alwaysCurrentFile);
@@ -290,6 +297,7 @@ protected slots:
 	void fileOpenRecent();
 	void fileOpenAllRecent(); ///< open all files in recent file list
 	void fileRecentList();
+    void fileClearRecentList();
 	void viewDocumentListHidden(); ///< show names of all hidden document (for debug)
 	void fileDocumentOpenFromChoosen(const QString &doc, int duplicate, int lineNr, int column);
 	void viewDocumentList();
@@ -328,7 +336,7 @@ private slots:
 	void fileDiffMerge();
 	void declareConflictResolved();
 protected slots:
-    void openExternalFile(QString name, const QString &defaultExt = "tex", LatexDocument *doc = nullptr); // signaled by latexViewer to open specific file
+    void openExternalFile(QString name, const QString &defaultExt = "tex", LatexDocument *doc = nullptr,bool relativeToCurrentDoc=false); // signaled by latexViewer to open specific file
     void openExternalFileFromAction();
 
 	void editUndo(); ///< undo changes in text editor
@@ -347,6 +355,7 @@ protected slots:
 	void editHardLineBreak();
 	void editHardLineBreakRepeat();
 	void editDeleteLine(); ///< delete current line in current text editor
+    void editCutLine(); ///< cut current line in current text editor
 	void editDeleteToEndOfLine();
 	void editDeleteFromStartOfLine();
 	void editMoveLineUp();
@@ -437,6 +446,7 @@ protected slots:
 	void updateLanguageToolStatus();
 	void editorSpellerChanged(const QString &name);
 	void changeEditorSpeller();
+    void showMoreDictionaries();
 	void insertSpellcheckMagicComment();
 	void updateStatusBarEncoding();
 	void addMagicRoot();
